# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.response_wrapper_course_module import ResponseWrapperCourseModule

class TestResponseWrapperCourseModule(unittest.TestCase):
    """ResponseWrapperCourseModule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperCourseModule:
        """Test ResponseWrapperCourseModule
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperCourseModule`
        """
        model = ResponseWrapperCourseModule()
        if include_optional:
            return ResponseWrapperCourseModule(
                done = True,
                result = public_api_server_connector_v2.models.course_module.CourseModule(
                    mandatory = True, 
                    is_published = True, 
                    is_active = True, 
                    title = '', 
                    public_description = '', 
                    short_description = '', 
                    image_id = '', 
                    available_at = 56, 
                    id = 56, 
                    course_id = 56, 
                    order = 56, 
                    submodules = [
                        public_api_server_connector_v2.models.course_submodule.CourseSubmodule(
                            order = 56, 
                            title = '', 
                            is_published = True, 
                            id = 56, 
                            module_id = 56, 
                            created_at = 56, )
                        ], 
                    lessons = [
                        public_api_server_connector_v2.models.module_lesson.ModuleLesson(
                            submodule_id = 56, 
                            thread_id = 56, 
                            lesson_type = null, 
                            image_id = '', 
                            title = '', 
                            payload = '', 
                            is_active = True, 
                            is_published = True, 
                            mandatory = True, 
                            id = 56, 
                            module_id = 56, 
                            order = 56, 
                            public_key = '', 
                            content_blocks = [
                                public_api_server_connector_v2.models.content_block.ContentBlock(
                                    block_type = null, 
                                    order = 56, 
                                    is_expanded = True, 
                                    content = null, 
                                    id = 56, 
                                    lesson_id = 56, 
                                    created_at = 56, )
                                ], 
                            attached_files = [
                                public_api_server_connector_v2.models.attached_file.AttachedFile(
                                    order = 56, 
                                    file_id = 56, 
                                    id = 56, 
                                    lesson_id = 56, 
                                    created_at = 56, )
                                ], )
                        ], ),
                error = ''
            )
        else:
            return ResponseWrapperCourseModule(
                done = True,
        )
        """

    def testResponseWrapperCourseModule(self):
        """Test ResponseWrapperCourseModule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.token_info import TokenInfo

class TestTokenInfo(unittest.TestCase):
    """TokenInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TokenInfo:
        """Test TokenInfo
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TokenInfo`
        """
        model = TokenInfo()
        if include_optional:
            return TokenInfo(
                api_key = public_api_server_connector_v2.models.api_key_get.ApiKeyGet(
                    name = '', 
                    id = 56, 
                    portal_id = 56, 
                    permissions = {
                        'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                            create = True, 
                            read = True, 
                            update = True, 
                            delete = True, )
                        }, 
                    openapi_specification_url = '', 
                    created_at = 56, 
                    last_used_at = 56, 
                    updated_at = 56, 
                    expires_at = 56, 
                    revoked_at = 56, ),
                portal = public_api_server_connector_v2.models.portal_info.PortalInfo(
                    id = 56, 
                    domain = '', ),
                owner = public_api_server_connector_v2.models.portal_member_base.PortalMemberBase(
                    id = 56, 
                    email = '', )
            )
        else:
            return TokenInfo(
                api_key = public_api_server_connector_v2.models.api_key_get.ApiKeyGet(
                    name = '', 
                    id = 56, 
                    portal_id = 56, 
                    permissions = {
                        'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                            create = True, 
                            read = True, 
                            update = True, 
                            delete = True, )
                        }, 
                    openapi_specification_url = '', 
                    created_at = 56, 
                    last_used_at = 56, 
                    updated_at = 56, 
                    expires_at = 56, 
                    revoked_at = 56, ),
                portal = public_api_server_connector_v2.models.portal_info.PortalInfo(
                    id = 56, 
                    domain = '', ),
                owner = public_api_server_connector_v2.models.portal_member_base.PortalMemberBase(
                    id = 56, 
                    email = '', ),
        )
        """

    def testTokenInfo(self):
        """Test TokenInfo"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.models.api_key_get import ApiKeyGet

class TestApiKeyGet(unittest.TestCase):
    """ApiKeyGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ApiKeyGet:
        """Test ApiKeyGet
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ApiKeyGet`
        """
        model = ApiKeyGet()
        if include_optional:
            return ApiKeyGet(
                name = '',
                id = 56,
                portal_id = 56,
                permissions = {
                    'key' : public_api_server_connector_v2.models.category_permissions.CategoryPermissions(
                        create = True, 
                        read = True, 
                        update = True, 
                        delete = True, )
                    },
                openapi_specification_url = '',
                created_at = 56,
                last_used_at = 56,
                updated_at = 56,
                expires_at = 56,
                revoked_at = 56
            )
        else:
            return ApiKeyGet(
                name = '',
                id = 56,
                portal_id = 56,
                created_at = 56,
        )
        """

    def testApiKeyGet(self):
        """Test ApiKeyGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class HttpMethod(str, Enum):
    """
    An enumeration.
    """

    """
    allowed enum values
    """
    GET = 'GET'
    POST = 'POST'
    PUT = 'PUT'
    PATCH = 'PATCH'
    DELETE = 'DELETE'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of HttpMethod from a JSON string"""
        return cls(json.loads(json_str))





# coding: utf-8

"""
    Mentortools Public API

    Mentortools public API service

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from public_api_server_connector_v2.api.api_spec_api import ApiSpecApi


class TestApiSpecApi(unittest.IsolatedAsyncioTestCase):
    """ApiSpecApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = ApiSpecApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_api_spec_count_spec_methods(self) -> None:
        """Test case for api_spec_count_spec_methods

        Count Spec Methods
        """
        pass

    async def test_api_spec_get_spec(self) -> None:
        """Test case for api_spec_get_spec

        Get Spec
        """
        pass

    async def test_api_spec_get_spec_methods(self) -> None:
        """Test case for api_spec_get_spec_methods

        Get Spec Methods
        """
        pass

    async def test_api_spec_get_spec_ui(self) -> None:
        """Test case for api_spec_get_spec_ui

        Get Spec Ui
        """
        pass


if __name__ == '__main__':
    unittest.main()
